==> crypto-2.6.1.tgz: package/Blk/Blk.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Blk = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zm7.1-20.87c-.047-2.914-3.401-3.66-3.401-3.66s1.882 1.266 1.93 3.829c.047 2.563-.965 3.563-.965 3.563s2.483-.819 2.436-3.732zM11.936 24.819V7.169L8.5 7v.289s2.103.554 2.103 3.748v9.64c0 3.773-2.103 3.99-2.103 3.99v.32zm5.492.18c1.494-.011 3.789-1.058 4.213-3.912.423-2.854-.67-4.166-1.236-4.648-.565-.481-2.165-1.035-2.165-1.035s1.058-.542 1.541-1.325.86-2.215.506-3.72c-.353-1.505-1.647-3.01-3.154-3.227-1.506-.216-2.145.036-3.973.06v17.61s2.773.21 4.268.197zm3.971-.65s3.136-.903 3.1-4.334c-.034-3.431-3.1-4.202-3.1-4.202s1.487 1.354 1.558 4.235S21.4 24.35 21.4 24.35zm-3.1-10.334c-1.099 1.461-3.836 1.076-3.836 1.076s-.013-6.166.258-6.431c.27-.265 1.671-.735 3 .205 1.33.94 1.676 3.689.577 5.15zm.203 2.625c1.028.457 2.33 2.014 1.695 4.526-.635 2.513-2.565 2.585-3.577 2.545-1.012-.04-1.986-.024-2.095-2.938s-.063-4.47-.063-4.47 3.012-.121 4.04.337z"
  }));
});
Blk.displayName = 'Blk';
export const BlkDimensions = {
  height: 32,
  width: 32
};

==> crypto-2.7.1.tgz: package/Blk/Blk.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Blk = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zm7.1-20.87c-.047-2.914-3.401-3.66-3.401-3.66s1.882 1.266 1.93 3.829c.047 2.563-.965 3.563-.965 3.563s2.483-.819 2.436-3.732zM11.936 24.819V7.169L8.5 7v.289s2.103.554 2.103 3.748v9.64c0 3.773-2.103 3.99-2.103 3.99v.32zm5.492.18c1.494-.011 3.789-1.058 4.213-3.912.423-2.854-.67-4.166-1.236-4.648-.565-.481-2.165-1.035-2.165-1.035s1.058-.542 1.541-1.325.86-2.215.506-3.72c-.353-1.505-1.647-3.01-3.154-3.227-1.506-.216-2.145.036-3.973.06v17.61s2.773.21 4.268.197zm3.971-.65s3.136-.903 3.1-4.334c-.034-3.431-3.1-4.202-3.1-4.202s1.487 1.354 1.558 4.235S21.4 24.35 21.4 24.35zm-3.1-10.334c-1.099 1.461-3.836 1.076-3.836 1.076s-.013-6.166.258-6.431c.27-.265 1.671-.735 3 .205 1.33.94 1.676 3.689.577 5.15zm.203 2.625c1.028.457 2.33 2.014 1.695 4.526-.635 2.513-2.565 2.585-3.577 2.545-1.012-.04-1.986-.024-2.095-2.938s-.063-4.47-.063-4.47 3.012-.121 4.04.337z"
  }));
});
Blk.displayName = 'Blk';
export var BlkDimensions = {
  height: 32,
  width: 32
};
